summaryrefslogtreecommitdiff
path: root/tests/debug-domain.c
diff options
context:
space:
mode:
authorJonny Lamb <jonny.lamb@collabora.co.uk>2010-04-29 15:38:27 +0100
committerJonny Lamb <jonny.lamb@collabora.co.uk>2010-04-29 17:11:52 +0100
commit456d7d6b8ecb56c1f646748f3c16ed97aab9d013 (patch)
tree4bb57cda56cb871238d30a84cfe2d1ff960a8b09 /tests/debug-domain.c
parent33823e022238472b924cdf122a493ce658622794 (diff)
downloadtelepathy-glib-456d7d6b8ecb56c1f646748f3c16ed97aab9d013.tar.gz
debug-internal: add more debug levels
Fixes fd.o#27899 Signed-off-by: Jonny Lamb <jonny.lamb@collabora.co.uk>
Diffstat (limited to 'tests/debug-domain.c')
-rw-r--r--tests/debug-domain.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/tests/debug-domain.c b/tests/debug-domain.c
index 7614c84aa..a26e2faac 100644
--- a/tests/debug-domain.c
+++ b/tests/debug-domain.c
@@ -5,7 +5,7 @@
#include "telepathy-glib/debug-internal.h"
/* Only run test if ENABLE_DEBUG is defined, otherwise we won't have
* _tp_debug and the TpDebugFlags enum. */
#ifdef ENABLE_DEBUG
typedef struct
@@ -37,6 +37,7 @@ handler (const gchar *log_domain,
parts = g_strsplit (log_domain, "/", -1);
+ g_assert_cmpuint (log_level, ==, G_LOG_LEVEL_DEBUG);
g_assert_cmpuint (g_strv_length (parts), ==, 2);
g_assert (!tp_strdiff (parts[0], "tp-glib"));
g_assert (!tp_strdiff (parts[1], i.domain));
@@ -60,7 +61,7 @@ int main (int argc, char **argv)
for (; items[item].domain != NULL; item++)
{
i = items[item];
- _tp_debug (i.flag, "foo");
+ _tp_log (G_LOG_LEVEL_DEBUG, i.flag, "foo");
}
#else
@@ -5,7 +5,7 @@
#include "telepathy-glib/debug-internal.h"
/* Only run test if ENABLE_DEBUG is defined, otherwise we won't have
- * _tp_debug and the TpDebugFlags enum. */
+ * _tp_log and the TpDebugFlags enum. */
#ifdef ENABLE_DEBUG
typedef struct